CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
75 lines
3.0 KiB
C++
75 lines
3.0 KiB
C++
/******************************************************************************
|
|
* Copyright (c) Advanced Micro Devices, Inc. All rights reserved.
|
|
*
|
|
* SPDX-License-Identifier: MIT
|
|
******************************************************************************/
|
|
|
|
#ifndef TILE_BROADCAST_TESTER_HPP
|
|
#define TILE_BROADCAST_TESTER_HPP
|
|
|
|
#include "tester.hpp"
|
|
|
|
using namespace rocshmem;
|
|
|
|
/******************************************************************************
|
|
* DEVICE TEST KERNELS
|
|
*****************************************************************************/
|
|
// Thread-level broadcast test - single WG, single wave
|
|
__global__ void TileBroadcastThreadTest(rocshmem_team_t team,
|
|
float *source, float *dest,
|
|
int tile_extent_0, int tile_extent_1,
|
|
int my_world_pe, int pe_root,
|
|
ShmemContextType ctx_type,
|
|
int *error_flag);
|
|
|
|
// Wave-level broadcast test - single WG, single wave
|
|
__global__ void TileBroadcastWaveTest(rocshmem_team_t team,
|
|
float *source, float *dest,
|
|
int tile_extent_0, int tile_extent_1,
|
|
int my_world_pe, int pe_root,
|
|
ShmemContextType ctx_type,
|
|
int wf_size,
|
|
int *error_flag);
|
|
|
|
// Workgroup-level broadcast test - multiple WGs with different teams
|
|
__global__ void TileBroadcastTest(rocshmem_team_t *teams, int num_teams,
|
|
float *source, float *dest,
|
|
int tile_extent_0, int tile_extent_1,
|
|
int my_world_pe, int pe_root,
|
|
ShmemContextType ctx_type,
|
|
int *error_flag);
|
|
|
|
/******************************************************************************
|
|
* HOST TESTER CLASS
|
|
*****************************************************************************/
|
|
class TileBroadcastTester : public Tester {
|
|
public:
|
|
explicit TileBroadcastTester(TesterArguments args);
|
|
|
|
virtual ~TileBroadcastTester();
|
|
|
|
virtual void resetBuffers(size_t size) override;
|
|
|
|
virtual void preLaunchKernel() override;
|
|
|
|
virtual void launchKernel(dim3 gridSize, dim3 blockSize, int loop,
|
|
size_t size) override;
|
|
|
|
virtual void postLaunchKernel() override;
|
|
|
|
virtual void verifyResults(size_t size) override;
|
|
|
|
protected:
|
|
rocshmem_team_t *teams; // Array of teams
|
|
int num_teams; // Number of teams to create
|
|
|
|
float *source; // Source tile data
|
|
float *dest; // Destination tile data
|
|
int tile_extent_0; // Tile dimension 0
|
|
int tile_extent_1; // Tile dimension 1
|
|
|
|
int *error_flag; // Device error flag for verification
|
|
};
|
|
|
|
#endif // TILE_BROADCAST_TESTER_HPP
|